@@ -1,10 +1,11 @@
-# Copyright (C) 2019-2020  The Software Heritage developers
+# Copyright (C) 2019-2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
 import logging
 import os
+from typing import Any, Dict
 
 from swh.core import config
 from swh.core.api import RPCServerApp
@@ -13,8 +14,11 @@ from swh.core.api import error_handler
 from swh.search.metrics import timed
 
 from .. import get_search
+from ..exc import SearchException
 from ..interface import SearchInterface
 
+logger = logging.getLogger(__name__)
+
 
 def _get_search():
     global search
@@ -29,6 +33,11 @@ app = RPCServerApp(__name__, backend_class=SearchInterface, backend_factory=_get
 search = None
 
 
+@app.errorhandler(SearchException)
+def search_error_handler(exception):
+    return error_handler(exception, encode_data, status_code=400)
+
+
 @app.errorhandler(Exception)
 def my_error_handler(exception):
     return error_handler(exception, encode_data)
@@ -40,16 +49,24 @@ def index():
     return "SWH Search API server"
 
 
+@app.before_first_request
+def initialized_index():
+    search = _get_search()
+    if app.config["search"]["cls"] == "elasticsearch":
+        logger.info("Initializing indexes with configuration: ", search.origin_config)
+    search.initialize()
+
+
 api_cfg = None
 
 
-def load_and_check_config(config_file, type="elasticsearch"):
+def load_and_check_config(config_file: str) -> Dict[str, Any]:
     """Check the minimal configuration is set to run the api or raise an
        error explanation.
 
     Args:
-        config_file (str): Path to the configuration file to load
-        type (str): configuration type. For 'local' type, more
+        config_file: Path to the configuration file to load
+        type: configuration type. For 'local' type, more
                     checks are done.
 
     Raises:
@@ -74,10 +91,10 @@ def load_and_check_config(config_file, type="elasticsearch"):
 
 def make_app_from_configfile():
     """Run the WSGI app from the webserver, loading the configuration from
-       a configuration file.
+    a configuration file.
 
-       SWH_CONFIG_FILENAME environment variable defines the
-       configuration path to load.
+    SWH_CONFIG_FILENAME environment variable defines the
+    configuration path to load.
 
     """
     global api_cfg
