@@ -4,11 +4,13 @@
 # See top-level LICENSE file for more information
 
 import copy
+from datetime import datetime, timezone
 import tempfile
 
 from click.testing import CliRunner
 from confluent_kafka import Producer
 import pytest
+from typing_extensions import Literal
 import yaml
 
 from swh.journal.serializers import value_to_kafka
@@ -21,7 +23,13 @@ search:
     cls: elasticsearch
     hosts:
     - '%(elasticsearch_host)s'
-    index_prefix: test
+    indexes:
+        origin:
+            index: test
+            read_alias: test-read
+            write_alias: test-write
+storage:
+    cls: memory
 """
 
 JOURNAL_OBJECTS_CONFIG_TEMPLATE = """
@@ -65,6 +73,7 @@ def test__journal_client__origin(
     value = value_to_kafka(origin_foobar_baz)
     topic = f"{kafka_prefix}.origin"
     producer.produce(topic=topic, key=b"bogus-origin", value=value)
+    producer.flush()
 
     journal_objects_config = JOURNAL_OBJECTS_CONFIG_TEMPLATE.format(
         broker=kafka_server, prefix=kafka_prefix, group_id="test-consumer"
@@ -105,63 +114,10 @@ def test__journal_client__origin(
     assert actual_page.results == []
 
 
-def test__journal_client__origin_visit(
-    swh_search, elasticsearch_host, kafka_prefix: str, kafka_server
-):
-    """Tests the re-indexing when origin_batch_size*task_batch_size is a
-    divisor of nb_origins."""
-    origin_foobar = {"url": "http://baz.foobar"}
-    producer = Producer(
-        {
-            "bootstrap.servers": kafka_server,
-            "client.id": "test search origin visit producer",
-            "acks": "all",
-        }
-    )
-    topic = f"{kafka_prefix}.origin_visit"
-    value = value_to_kafka({"origin": origin_foobar["url"], "type": "git"})
-    producer.produce(topic=topic, key=b"bogus-origin-visit", value=value)
-
-    journal_objects_config = JOURNAL_OBJECTS_CONFIG_TEMPLATE.format(
-        broker=kafka_server, prefix=kafka_prefix, group_id="test-consumer"
-    )
-    result = invoke(
-        False,
-        [
-            "journal-client",
-            "objects",
-            "--stop-after-objects",
-            "1",
-            "--object-type",
-            "origin_visit",
-        ],
-        journal_objects_config,
-        elasticsearch_host=elasticsearch_host,
-    )
-
-    # Check the output
-    expected_output = "Processed 1 messages.\nDone.\n"
-    assert result.exit_code == 0, result.output
-    assert result.output == expected_output
-
-    swh_search.flush()
-
-    actual_page = swh_search.origin_search(url_pattern="foobar", with_visit=False)
-    assert actual_page.next_page_token is None
-    assert actual_page.results == [origin_foobar]
-
-    # Not considered visited unless the visit is full
-    actual_page = swh_search.origin_search(url_pattern="foobar", with_visit=True)
-    assert actual_page.next_page_token is None
-    assert actual_page.results == []
-
-
 def test__journal_client__origin_visit_status(
     swh_search, elasticsearch_host, kafka_prefix: str, kafka_server
 ):
-    """Subscribing to origin-visit-status should result in swh-search indexation
-
-    """
+    """Subscribing to origin-visit-status should result in swh-search indexation"""
     origin_foobar = {"url": "http://baz.foobar"}
     producer = Producer(
         {
@@ -175,11 +131,14 @@ def test__journal_client__origin_visit_status(
         {
             "origin": origin_foobar["url"],
             "visit": 1,
+            "type": "git",
+            "date": datetime.now(tz=timezone.utc),
             "snapshot": None,
             "status": "full",
         }
     )
     producer.produce(topic=topic, key=b"bogus-origin-visit-status", value=value)
+    producer.flush()
 
     journal_objects_config = JOURNAL_OBJECTS_CONFIG_TEMPLATE.format(
         broker=kafka_server, prefix=kafka_prefix, group_id="test-consumer"
@@ -217,15 +176,18 @@ def test__journal_client__origin_visit_status(
     assert actual_page.results == [origin_foobar]
 
 
-def test__journal_client__origin_intrinsic_metadata(
-    swh_search, elasticsearch_host, kafka_prefix: str, kafka_server
+@pytest.mark.parametrize("metadata_source", ["intrinsic", "extrinsic"])
+def test__journal_client__origin_metadata(
+    swh_search,
+    elasticsearch_host,
+    kafka_prefix: str,
+    kafka_server,
+    metadata_source: Literal["intrinsic", "extrinsic"],
 ):
-    """Subscribing to origin-intrinsic-metadata should result in swh-search indexation
-
-    """
+    """Subscribing to origin-intrinsic-metadata should result in swh-search indexation"""
     origin_foobar = {"url": "https://github.com/clojure/clojure"}
 
-    origin_intrinsic_metadata = {
+    origin_metadata = {
         "id": origin_foobar["url"],
         "metadata": {
             "name": "clojure",
@@ -238,9 +200,27 @@ def test__journal_client__origin_intrinsic_metadata(
             "codeRepository": "https://repo.maven.apache.org/maven2/org/clojure/clojure",  # noqa
         },
         "indexer_configuration_id": 1,
-        "from_revision": hash_to_bytes("f47c139e20970ee0852166f48ee2a4626632b86e"),
-        "mappings": ["maven"],
     }
+    if metadata_source == "intrinsic":
+        origin_metadata.update(
+            {
+                "from_revision": hash_to_bytes(
+                    "f47c139e20970ee0852166f48ee2a4626632b86e"
+                ),
+                "mappings": ["maven"],
+            }
+        )
+    elif metadata_source == "extrinsic":
+        origin_metadata.update(
+            {
+                "from_revision": hash_to_bytes(
+                    "f47c139e20970ee0852166f48ee2a4626632b86e"
+                ),
+                "mappings": ["github"],
+            }
+        )
+    else:
+        assert False, metadata_source
 
     producer = Producer(
         {
@@ -249,9 +229,10 @@ def test__journal_client__origin_intrinsic_metadata(
             "acks": "all",
         }
     )
-    topic = f"{kafka_prefix}.origin_intrinsic_metadata"
-    value = value_to_kafka(origin_intrinsic_metadata)
-    producer.produce(topic=topic, key=b"bogus-origin-intrinsic-metadata", value=value)
+    topic = f"{kafka_prefix}.origin_{metadata_source}_metadata"
+    value = value_to_kafka(origin_metadata)
+    producer.produce(topic=topic, key=b"bogus-origin-metadata", value=value)
+    producer.flush()
 
     journal_objects_config = JOURNAL_OBJECTS_CONFIG_TEMPLATE.format(
         broker=kafka_server, prefix=kafka_prefix, group_id="test-consumer"
@@ -264,7 +245,7 @@ def test__journal_client__origin_intrinsic_metadata(
             "--stop-after-objects",
             "1",
             "--object-type",
-            "origin_intrinsic_metadata",
+            f"origin_{metadata_source}_metadata",
         ],
         journal_objects_config,
         elasticsearch_host=elasticsearch_host,
@@ -293,7 +274,12 @@ def test__journal_client__missing_main_journal_config_key(elasticsearch_host):
     with pytest.raises(KeyError, match="journal"):
         invoke(
             catch_exceptions=False,
-            args=["journal-client", "objects", "--stop-after-objects", "1",],
+            args=[
+                "journal-client",
+                "objects",
+                "--stop-after-objects",
+                "1",
+            ],
             config="",  # missing config will make it raise
             elasticsearch_host=elasticsearch_host,
         )
@@ -392,19 +378,45 @@ journal:
         )
 
 
-def test__initialize__with_prefix(elasticsearch_host):
-    """Initializing the index with a prefix should create an <prefix>_origin index"""
+def test__initialize__with_index_name(elasticsearch_host):
+    """Initializing the index with an index name should create the right index"""
 
     search = get_search(
-        "elasticsearch", hosts=[elasticsearch_host], index_prefix="test"
+        "elasticsearch",
+        hosts=[elasticsearch_host],
+        indexes={"origin": {"index": "test"}},
     )
 
-    assert search.origin_index == "test_origin"
+    assert search._get_origin_index() == "test"
+    assert search._get_origin_read_alias() == "origin-read"
+    assert search._get_origin_write_alias() == "origin-write"
 
 
-def test__initialize__without_prefix(elasticsearch_host):
-    """Initializing the index without a prefix should create an origin index"""
+def test__initialize__with_read_alias(elasticsearch_host):
+    """Initializing the index with a search alias name should create
+    the right search alias"""
 
-    search = get_search("elasticsearch", hosts=[elasticsearch_host])
+    search = get_search(
+        "elasticsearch",
+        hosts=[elasticsearch_host],
+        indexes={"origin": {"read_alias": "test"}},
+    )
 
-    assert search.origin_index == "origin"
+    assert search._get_origin_index() == "origin"
+    assert search._get_origin_read_alias() == "test"
+    assert search._get_origin_write_alias() == "origin-write"
+
+
+def test__initialize__with_write_alias(elasticsearch_host):
+    """Initializing the index with an indexing alias name should create
+    the right indexing alias"""
+
+    search = get_search(
+        "elasticsearch",
+        hosts=[elasticsearch_host],
+        indexes={"origin": {"write_alias": "test"}},
+    )
+
+    assert search._get_origin_index() == "origin"
+    assert search._get_origin_read_alias() == "origin-read"
+    assert search._get_origin_write_alias() == "test"
